@@ -3,11 +3,17 @@ from datetime import datetime
 from tutuka_client.utils import iso8601_without_underscore
 
 
-def normalize_argument(argument):
+def checksum_normalize(argument):
     if isinstance(argument, str):
         return argument
     if isinstance(argument, datetime):
         return iso8601_without_underscore(argument)
     if isinstance(argument, int):
         return str(argument)
-    raise TypeError('cant normalize argument')
+    raise Exception('cant normalize argument')
+
+
+def date_time_normalize(argument):
+    if isinstance(argument, datetime):
+        return argument.isoformat()
+    return argument
